package org.rcisoft.sys.user.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.common.component.Global;
import org.rcisoft.common.controller.PaginationController;
import org.rcisoft.common.model.GridModel;
import org.rcisoft.core.constant.MessageConstant;
import org.rcisoft.core.exception.ServiceException;
import org.rcisoft.core.model.PersistModel;
import org.rcisoft.core.result.Result;
import org.rcisoft.core.result.ResultServiceEnums;
import org.rcisoft.core.util.UserUtil;
import org.rcisoft.sys.menu.entity.SysMenu;
import org.rcisoft.sys.user.bean.CurUser;
import org.rcisoft.sys.user.dao.SysUserMapper;
import org.rcisoft.sys.user.dto.QuerySysUserDTO;
import org.rcisoft.sys.user.entity.SysUser;
import org.rcisoft.sys.user.service.SysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.expression.spel.ast.Assign;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import springfox.documentation.annotations.ApiIgnore;

import javax.validation.Valid;
import java.util.List;

/**
 * Created by Andrew on 2017/7/6.
 */
@Api(tags = "7 用户管理")
@RestController
@RequestMapping(value = "/user")
public class SysUserController extends PaginationController<SysUser> {

    @Autowired
    private SysUserService userServiceImpl;

    @Autowired
    private Global global;

    @ApiOperation(value = "701 分页查询用户", notes = "分页查询用户")
    @ApiImplicitParams({@ApiImplicitParam(name = "name", value = "用户名（模糊查询条件）", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "flag", value = "用户启用状态  0未启用  1启用", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "roleName", value = "用户角色", required = false, dataType = "varchar")})
    @GetMapping(value = "/queryUsers")
    public GridModel queryUsers(CurUser curUser, @Valid QuerySysUserDTO dto, BindingResult br) {
        userServiceImpl.queryUsersByPagination(getPaginationUtility(), dto);
        GridModel gridModel = getGridModelResponse();
        return gridModel;
    }

    @ApiOperation(value = "702 分配角色", notes = "分配角色")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "用户id（批量操作时 id用，隔开）", required = true, dataType = "varchar", paramType = "path"),
            @ApiImplicitParam(name = "roleId", value = "角色id（批量操作时 id用，隔开）", required = true, dataType = "varchar", paramType = "path")})
    @PostMapping(value = "/AssignRoles")
    public Result AssignRoles(CurUser curUser, @Valid String id, BindingResult br,String roleId) {
        int line = userServiceImpl.AssignRoles(id,roleId);
        return Result.builder(new PersistModel(line),
                MessageConstant.MESSAGE_ALERT_SUCCESS,
                MessageConstant.MESSAGE_ALERT_ERROR,
                id);
    }

//    @ApiOperation(value = "703 删除用户", notes = "删除用户")
//    @ApiImplicitParam(name = "businessId", value = "用户id", required = true, dataType = "varchar", paramType = "path")
//    @PostMapping(value = "/delete")
//    public Result roleDelete(CurUser curUser, @Valid String businessId, BindingResult br) {
//        int line = userServiceImpl.removeUser(businessId);
//        return Result.builder(new PersistModel(line),
//                MessageConstant.MESSAGE_ALERT_SUCCESS,
//                MessageConstant.MESSAGE_ALERT_ERROR,
//                businessId);
//    }

    @ApiOperation(value = "704 停用用户", notes = "停用用户")
    @ApiImplicitParam(name = "businessId", value = "用户Id（批量操作时 id用，隔开）", required = true, dataType = "varchar", paramType = "path")
    @PostMapping(value = "/stop")
    public Result stop(CurUser curUser, @Valid String businessId, BindingResult br) {
        int line = userServiceImpl.stopUserByUserBusinessId(businessId);
        return Result.builder(new PersistModel(line),
                MessageConstant.MESSAGE_ALERT_SUCCESS,
                MessageConstant.MESSAGE_ALERT_ERROR,
                businessId);
    }

    @ApiOperation(value = "705 启用用户", notes = "启用用户")
    @ApiImplicitParam(name = "businessId", value = "用户Id（批量操作时 id用，隔开）", required = true, dataType = "varchar", paramType = "path")
    @PostMapping(value = "/start")
    public Result Start(CurUser curUser, @Valid String businessId, BindingResult br) {
        int line = userServiceImpl.startUserByUserBusinessId(businessId);
        return Result.builder(new PersistModel(line),
                MessageConstant.MESSAGE_ALERT_SUCCESS,
                MessageConstant.MESSAGE_ALERT_ERROR,
                businessId);
    }

    /**
     * 查询菜单
     *
     * @param user
     * @return
     */
    @GetMapping(value = "/queryMyMenu")
    public Result queryMyMenu(CurUser user) {
        List<SysMenu> menus = userServiceImpl.queryUserMenus(user);
        return Result.builder(new PersistModel(1),
                MessageConstant.MESSAGE_ALERT_SUCCESS,
                MessageConstant.MESSAGE_ALERT_ERROR,
                menus);
    }

}
