package org.rcisoft.sys.user.dao;


import org.apache.ibatis.annotations.*;
import org.rcisoft.core.base.BaseMapper;
import org.rcisoft.sys.user.dto.QuerySysUserDTO;
import org.rcisoft.sys.user.entity.SysUser;
import org.rcisoft.sys.user.entity.UserRole;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * Created by lcy on 17/8/9.
 */
@Repository
public interface SysUserMapper extends BaseMapper<SysUser> {

    @Select("<script>select su.* ,sr.role_name as roleList from s_user  as su " +
            "left join s_r_user_role as ru on su.business_id = ru.user_id " +
            "left join s_role as sr on ru.role_id = sr.business_id " +
            "where su.del_flag = 0" +
            "<if test=\"name!=null and name != ''\"> and su.name like CONCAT('%',#{name},'%') </if>" +
            "<if test=\"roleName!=null and roleName != ''\"> and sr.role_name = #{roleName}</if>" +
            "<if test=\"flag!=null and flag != ''\"> and su.flag = #{flag}</if></script>")
    @ResultMap(value = "BaseResultMap")
    List<SysUser> queryUsers(QuerySysUserDTO dto);

    @Select("<script>SELECT sr.role_name AS roleList  " +
            "FROM s_user AS su " +
            "LEFT JOIN s_r_user_role AS ru ON su.business_id = ru.user_id " +
            "LEFT JOIN s_role AS sr ON ru.role_id = sr.business_id  " +
            "WHERE su.del_flag = 0  " +
            "AND su.business_id = #{businessId}</script>")
    List<String> queryRoleByUserId(@Param("businessId") String businessId);

    @Update("<script> update s_user set flag = '1' where business_id in" +
            "<foreach item='item' index='index' collection='businessId' open='(' separator=',' close=')'> #{item} </foreach> " +
            "</script>")
    int startFlag(@Param("businessId") List<String> businessId);

    @Update("<script> update s_user set flag = '0' where business_id in" +
            "<foreach item='item' index='index' collection='businessId' open='(' separator=',' close=')'> #{item} </foreach> " +
            "</script>")
    int stopFlag(@Param("businessId") List<String> businessId);

    @Select("<script>select ur.user_id from s_r_user_role ur left JOIN s_role  sr on ur.role_id = sr.business_id where sr.role_name in" +
            "<foreach item='item' index='index' collection='roleName' open='(' separator=',' close=')'> #{item} </foreach> " +
            "</script>")
    List<String> adminId(@Param("roleName") List<String> roleName);

    @Select("<script> select * from s_r_user_role where user_id in" +
            " <foreach item='item' index='index' collection='userId' open='(' separator=',' close=')'> #{item} </foreach>" +
            "</script>")
    List<UserRole> queryUserRoleById(@Param("userId") List<String> userId);

    @Delete("<script> DELETE from  s_r_user_role where user_id in" +
            " <foreach item='item' index='index' collection='userId' open='(' separator=',' close=')'> #{item} </foreach>" +
            "</script>")
    int delUserRoleById(@Param("userId") List<String> userId);

    @Insert("<script> insert into s_r_user_role VALUES " +
            "<foreach collection=\"list\" item=\"item\" separator=\",\">" +
            "( #{item.businessId},#{item.userId},#{item.roleId})" +
            "</foreach></script>")
    int insertUserRoleById(List<UserRole> userRoles);

    @Select("<script>select * from s_user where login_name = #{username} and del_flag = 0 </script>")
    @ResultMap(value = "BaseResultMap")
    List<SysUser> queryUserByName(String username);

    @Insert("<script>INSERT INTO s_user" +
            "(create_date,update_date,create_by,update_by,remarks,del_flag,flag,business_id,login_name,password,name,sex,git_lab_id,git_lab_username,git_lab_impression_token,head_pic,email)VALUES" +
            "<foreach collection=\"list\" item=\"item\" separator=\",\">" +
            "( #{item.createDate},#{item.updateDate},#{item.createBy},#{item.updateBy},#{item.remarks},#{item.delFlag},#{item.flag},#{item.businessId},#{item.loginName},#{item.password},#{item.name},#{item.sex},#{item.gitLabId},#{item.gitLabUsername},#{item.gitLabImpressionToken},#{item.headPic},#{item.email})" +
            "</foreach></script>")
    int insertList(List<SysUser> users);

    @Insert("<script>INSERT INTO s_r_user_role" +
            "(business_id,user_id,role_id)VALUES" +
            "<foreach collection=\"list\" item=\"item\" separator=\",\">" +
            "(#{item.businessId},#{item.userId},#{item.roleId})" +
            "</foreach></script>")
    int insertUserRoleList(List<UserRole> users);

    @Insert("INSERT INTO s_r_user_role" +
            "(business_id,user_id,role_id)VALUES" +
            "(#{businessId},#{userId},#{roleId})")
    int insertUserRole(UserRole userRole);

    @Select("SELECT u.business_id from s_user u left join ${tab} s on u.login_name = s.code where s.business_id = #{id} and u.del_flag = 0")
    String selectUserIdByStuOrTeaId(@Param("id") String id, @Param("tab") String table);

    @Delete("delete from s_user where login_name = #{code}")
    int deleteByCode(String code);

    /**
     * 用户删除 cy 5-15
     *
     * @param code
     * @return
     */
    @Delete("DELETE s " +
            "FROM " +
            " s_user s " +
            "LEFT JOIN b_company c ON c. CODE = s.login_name " +
            "WHERE " +
            " c.business_id = #{code}")
    int deleteByCompany(String code);


    @Select("<script>select * from s_user where business_id = #{userId} and password = #{password} limit 1</script>")
    @ResultMap(value = "BaseResultMap")
    SysUser checkPassword(@Param("userId") String userId, @Param("password") String password);

    @Update("update s_user set password =#{password} where business_id = '${userId}'")
    int changePassword(@Param("userId") String userId, @Param("password") String password);

    @Select("<script>select password from s_user where business_id = #{userId} </script>")
    String queryPasswordById(String userId);

    @Update("<script>update s_user set password = #{password} where 1=1 " +
            "and login_name = #{loginName} " +
            "and del_flag = 0</script>")
    int resetPassword(@Param("loginName") String loginNam, @Param("password") String password);

    @Select("<script>select business_id from s_user where login_name = #{studentCode} and del_flag = 0 and flag = 1</script>")
    String queryUserIdByLoginName(String studentCode);

    @Delete("<script>delete from s_r_user_role where user_id = #{businessId}</script>")
    int deleteUserRole(String businessId);

    @Select("<script>select su.*,ba.`name` as agencyName,sr.role_name as roleName,sr.business_id as roleId from s_user su " +
            "LEFT JOIN s_r_user_role sru on su.business_id = sru.user_id " +
            "LEFT JOIN s_role sr on sru.role_id = sr.business_id " +
            "where su.is_created = '1' and su.del_flag = 0 and su.flag = 1  " +
            "</script>")
    @ResultMap(value = "BaseResultMap")
    List<SysUser> queryCreatedUsers(SysUser sysUser);

    @Select("<script>select agency_code from s_user where business_id = #{businessId}</script>")
    String queryAgencyCodeByBusinessId(String businessId);


    @Update("update s_user set flag =#{flag} where login_name = #{loginName} and del_flag = 0 and flag = 0")
    int stopOrStartUser(SysUser user);

    @Update("update s_user set flag =#{flag} where business_id = #{businessId} ")
    int stopOrStartUserByUserBusinessId(SysUser sysUser);

    @Select("select business_id from s_user where login_name = #{0} and del_flag = 0")
    String selectByLoginName(String loginName);

    @Select("select count(*) from s_r_user_role " +
            "left join s_user on s_user.business_id = s_r_user_role.user_id " +
            "where role_id = #{roleId} and s_user.del_flag = 0 ")
    int countUserByRole(String roleId);


    int deleteTeacherUserRole(List<SysUser> userTeacherList);

    int deleteCompanyUserRole(List<SysUser> userCompanyList);
}
