package org.rcisoft.sys.user.service.impl;

import org.apache.commons.lang.StringUtils;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.aop.PageUtil;
import org.rcisoft.core.exception.ServiceException;
import org.rcisoft.core.result.ResultServiceEnums;
import org.rcisoft.core.util.UserUtil;
import org.rcisoft.sys.menu.dao.SysMenuRepository;
import org.rcisoft.sys.menu.entity.SysMenu;
import org.rcisoft.sys.user.bean.CurUser;
import org.rcisoft.sys.user.dao.SysUserMapper;
import org.rcisoft.sys.user.dto.QuerySysUserDTO;
import org.rcisoft.sys.user.entity.SysUser;
import org.rcisoft.sys.user.entity.UserRole;
import org.rcisoft.sys.user.service.SysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import static java.util.Arrays.asList;

@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
public class SysUserServiceImpl implements SysUserService {

    @Autowired
    private SysUserMapper sysUserMapper;

    @Autowired
    private SysMenuRepository sysMenuRepository;

    @Autowired
    private Global global;

    @Override
    public List<SysUser> queryUsersByPagination(PageUtil pageUtil, QuerySysUserDTO dto) {
        return sysUserMapper.queryUsers(dto);
    }

    @Override
    public int removeUser(String id) {
        SysUser user = new SysUser();
        user.setDeleted();
        user.setStop();
        user.setBusinessId(id);
        return sysUserMapper.deleteByPrimaryKey(user);
    }

    @Override
    public int AssignRoles(String userId, String roleId) {
        List<String> adminRoleName = asList("主管理员", "子管理员");
        List<String> adminIds = sysUserMapper.adminId(adminRoleName);
        if (adminIds.size() != 0) {
            for (int i = 0; i < adminIds.size(); i++) {
                userId = userId.replace(adminIds.get(i), "");
            }
            List<String> userIds = asList(StringUtils.split(userId, ","));
            List<String> roleIds = asList(StringUtils.split(roleId, ","));
            List<UserRole> userRoles = new ArrayList<>();
            sysUserMapper.delUserRoleById(userIds);
            int result = 0;
            for (int i = 0; i < roleIds.size(); i++) {
                for (int j = 0; j < userIds.size(); j++) {
                    UserRole userRole = new UserRole();
                    userRole.setUserId(userIds.get(j));
                    userRole.setRoleId(roleIds.get(i));
                    UserUtil.setCurrentPersistOperation(userRole);
                    userRoles.add(userRole);
                }
            }
            result += sysUserMapper.insertUserRoleById(userRoles);
            if (result > 0) {
                return 1;
            }
        }
        return 0;
    }

    @Override
    public void updateUser(SysUser user, String uid, int line) {
        if (!user.isEmpty()) {
            user.setBusinessId(uid);
            int l1 = sysUserMapper.updateByPrimaryKeySelective(user);
            if (l1 != line)
                throw new ServiceException(ResultServiceEnums.UPDATE_ERROR);
        }
    }

    @Override
    public String checkPassword(String userId) {
        return sysUserMapper.queryPasswordById(userId);
    }


    @Override
    public int stopOrStartUserByUserBusinessId(String businessId) {
        SysUser sysUser = sysUserMapper.selectByPrimaryKey(businessId);
        String status = sysUser.getFlag().equals("0") ? "1" : "0";
        sysUser.setFlag(status);
        return sysUserMapper.stopOrStartUserByUserBusinessId(sysUser);
    }

    @Override
    public int stopUserByUserBusinessId(String businessId) {
        List<String> ids = asList(StringUtils.split(businessId, ","));
        return sysUserMapper.stopFlag(ids);
    }

    @Override
    public int startUserByUserBusinessId(String businessId) {
        List<String> ids = asList(StringUtils.split(businessId, ","));
        return sysUserMapper.startFlag(ids);
    }

    @Override
    public List<SysMenu> queryUserMenus(CurUser user) {
        SysMenu sysMenu = new SysMenu();
        sysMenu.setNormal();
        sysMenu.setBusinessId(user.getUserId());
        return sysMenuRepository.queryMyMenu(sysMenu);
    }


}
